@@ -9,26 +9,28 @@ from seabreeze.pyseabreeze.features._base import SeaBreezeFeature
 class SeaBreezeIPv4Feature(SeaBreezeFeature):
     identifier = "ipv4"
 
-    def get_dhcp_enable_state(self, interface_index):
+    def get_dhcp_enable_state(self, interface_index: int) -> bool:
         raise NotImplementedError("implement in derived class")
 
-    def set_dhcp_enable_state(self, interface_index, is_enabled):
+    def set_dhcp_enable_state(self, interface_index: int, is_enabled: bool) -> None:
         raise NotImplementedError("implement in derived class")
 
-    def get_number_of_ipv4_addresses(self, interface_index):
+    def get_number_of_ipv4_addresses(self, interface_index: int) -> int:
         raise NotImplementedError("implement in derived class")
 
-    def get_ipv4_address(self, interface_index, address_index):
+    def get_ipv4_address(self, interface_index: int, address_index: int) -> str:
         raise NotImplementedError("implement in derived class")
 
-    def get_default_gateway(self, interface_index):
+    def get_default_gateway(self, interface_index: int) -> str:
         raise NotImplementedError("implement in derived class")
 
-    def set_default_gateway(self, interface_index, default_gateway_address):
+    def set_default_gateway(
+        self, interface_index: int, default_gateway_address: str
+    ) -> None:
         raise NotImplementedError("implement in derived class")
 
-    def add_ipv4_address(self, interface_index, ipv4_address):
+    def add_ipv4_address(self, interface_index: int, ipv4_address: str) -> None:
         raise NotImplementedError("implement in derived class")
 
-    def delete_ipv4_address(self, interface_index, address_index):
+    def delete_ipv4_address(self, interface_index: int, address_index: int) -> None:
         raise NotImplementedError("implement in derived class")
